aboutsummaryrefslogtreecommitdiff
path: root/install.sh
diff options
context:
space:
mode:
Diffstat (limited to 'install.sh')
-rwxr-xr-xinstall.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/install.sh b/install.sh
index 6cbdafa1..05ceacb8 100755
--- a/install.sh
+++ b/install.sh
@@ -1,7 +1,7 @@
#! /usr/bin/env bash
#
# This script install all dependencies and configure JARR.
# Usage:
# ./install.sh (sqlite|postgres)
#
@@ -67,7 +67,7 @@ elif [ "$1" == sqlite ]; then
echo "Configuring the SQLite database..."
echo '[database]' >> src/conf/conf.cfg
- echo 'database_url = sqlite:///jarr.db' >> src/conf/conf.cfg
+ echo 'database_url = sqlite:///newspipe.db' >> src/conf/conf.cfg
fi
@@ -83,5 +83,5 @@ git submodule update > /dev/null
echo "Installation terminated."
-echo "Launch JARR with the command:"
+echo "Launch Newspipe with the command:"
echo -e "\tpython$PYTHON_VERSION src/runserver.py"
bgstack15
@@ -1,7 +1,7 @@
#! /usr/bin/env bash
#
-# This script install all dependencies and configure JARR.
+# This script install all dependencies and configure Newspipe.
# Usage:
# ./install.sh (sqlite|postgres)